@@ -19,6 +19,6 @@
 ##  along with gettz.  If not, see <http://www.gnu.org/licenses/>.
 
 gettz <- function() {
-    val <- .Call("gettz_impl");
+    val <- .Call(gettz_impl);
     return(val)                         #return visibly
 }
